@@ -144,6 +144,7 @@ class ActionKeywords(LibraryContext):
         keys: str = None,
         interval: float = 0.01,
         wait_time: float = None,
+        send_enter: bool = False,
     ):
         """Send keys to desktop, current window or to Control element
         defined by given locator.
@@ -155,6 +156,7 @@ class ActionKeywords(LibraryContext):
         :param interval: time between sending keys, default 0.01 seconds
         :param wait_time: time to wait after sending keys, default is a
          library timeout
+        :param send_enter: if True then {Enter} is sent at the end of the keys
 
         Example:
 
@@ -162,12 +164,14 @@ class ActionKeywords(LibraryContext):
 
             Send Keys  desktop   {Ctrl}{F4}
             Send Keys  None   {Ctrl}{F4}
-            Send Keys  id:input5  username
+            Send Keys  id:input5  username   send_enter=True
             ${control}=   Get Control   id:pass
-            Send Keys  ${control}  password
+            Send Keys  ${control}  password   send_enter=True
         """
         element = self.ctx.get_element(locator)
         keys_wait_time = wait_time or self.ctx.timeout
+        if send_enter:
+            keys += "{Enter}"
         if hasattr(element, "SendKeys"):
             element.SendKeys(keys, interval=interval, waitTime=keys_wait_time)
         else:
@@ -225,7 +229,7 @@ class ActionKeywords(LibraryContext):
 
         .. code-block:: robotframework
 
-            Set Value   type:DataItem name:column1   abc
+            Set Value   type:DataItem name:column1   ab c  # Set value to "ab c"
         """
         element = self.ctx.get_element(locator)
         if hasattr(element, "GetValuePattern"):
