@@ -1,6 +1,6 @@
 from dataclasses import dataclass, field
 import re
-from typing import List
+from typing import List, Union
 from RPA.Windows.keywords import (
     ControlNotFound,
     keyword,
@@ -202,11 +202,19 @@ class LocatorKeywords(LibraryContext):
 
     @keyword
     def get_element(
-        self, locator: str, search_depth: int = 8, root_element: Control = None
+        self,
+        locator: Union[str, Control],
+        search_depth: int = 8,
+        root_element: Control = None,
     ) -> Control:
         """Get Control element defined by the locator.
 
-        :param locator: locator as a string
+        Returned element can be used instead of a locator string for
+        keywords accepting `locator`.
+
+        Keyword ``Get Attribute`` can be used to read element attribute values.
+
+        :param locator: locator as a string or as a element
         :param search_depth: how deep the element search will traverse (default 8)
         :param root_element: can be used to set search root element
         """
